@@ -8,7 +8,7 @@ import pytest
 import pandablob
 
 
-@pytest.mark.parametrize("file", ["csv", "json", "txt", "xls", "xlsx"])
+@pytest.mark.parametrize("file", ["csv", "json", "txt", "xls", "xlsx", "parquet"])
 def test_upload(file, test_files, dataframe_upload, mock_upload):
     """Mock uploading to the azure blob."""
 
@@ -28,5 +28,12 @@ def test_upload(file, test_files, dataframe_upload, mock_upload):
     pandablob_stream = MockAzureBlob.upload_blob.call_args[0][0]
 
     # Test result
+    if extension == ".parquet":
+        pandablob_stream = io.BytesIO(pandablob_stream)
     result_df = dataframe_upload(extension, pandablob_stream, stream=True)
+
+    if extension == ".parquet":
+        result_df.set_index("Unnamed: 0", drop=True, inplace=True)
+        df.set_index("Unnamed: 0", drop=True, inplace=True)
+
     assert df.equals(result_df)
